==> generator-react-2.0.1.tgz: package/generators/coreui/templates/src/Navigation.js <==
import React, { Component, Fragment } from 'react';
import { FontAwesomeIcon as Icon } from '@fortawesome/react-fontawesome'

import {
  faUser,
  faSignOutAlt
} from '@fortawesome/free-solid-svg-icons';

import {
  Nav,
  DropdownMenu,
  DropdownItem,
  DropdownToggle,
} from 'reactstrap';

import {
  AppAsideToggler,
  AppNavbarBrand,
  AppSidebarToggler,
  AppHeaderDropdown,
} from '@coreui/react';

export const items = [
  { name: 'Default', url: '/default', icon: 'fas fa-home' },
];

export default class Navigation extends Component {
  render() {
    return (
      <Fragment>
        <AppSidebarToggler className="d-lg-none" display="md" mobile />
        <AppNavbarBrand
          full={{ src: 'https://placeimg.com/89/25/any', width: 89, height: 25, alt: '<%= title %> logotype' }}
          minimized={{ src: 'https://placeimg.com/30/30/any', width: 30, height: 30, alt: '<%= title %> sygnet' }}
        />
        <AppSidebarToggler className="d-md-down-none" display="lg" />
        <Nav className="ml-auto" navbar>
          <AppHeaderDropdown direction="down">
            <DropdownToggle nav>
              <Icon icon={faUser} />
            </DropdownToggle>
            <DropdownMenu right style={{ right: 'auto' }}>
              <DropdownItem>
                <a
                  onClick={() => {}}
                >
                  <Icon icon={faSignOutAlt} className='mr-2' />
                  Logout
                </a>
              </DropdownItem>
            </DropdownMenu>
          </AppHeaderDropdown>
        </Nav>
        <AppAsideToggler className="d-md-down-none" />
      </Fragment>
    );
  }
}

==> generator-react-2.1.4.tgz: package/generators/coreui/templates/src/Navigation.js <==
import React, { Component, Fragment } from 'react';
import { FontAwesomeIcon as Icon } from '@fortawesome/react-fontawesome'

import {
  faUser,
  faSignOutAlt
} from '@fortawesome/free-solid-svg-icons';

import {
  Nav,
  DropdownMenu,
  DropdownItem,
  DropdownToggle,
} from 'reactstrap';

import {
  AppAsideToggler,
  AppNavbarBrand,
  AppSidebarToggler,
  AppHeaderDropdown,
} from '@coreui/react';

export const items = [
  { name: 'Default', url: '/default', icon: 'fas fa-home' },
];

class Navigation extends Component {
  render() {
    return (
      <Fragment>
        <AppSidebarToggler className="d-lg-none" display="md" mobile />
        <AppNavbarBrand
          full={{ src: 'https://placeimg.com/89/25/any', width: 89, height: 25, alt: '<%= title %> logotype' }}
          minimized={{ src: 'https://placeimg.com/30/30/any', width: 30, height: 30, alt: '<%= title %> sygnet' }}
        />
        <AppSidebarToggler className="d-md-down-none" display="lg" />
        <Nav className="ml-auto" navbar>
          <AppHeaderDropdown direction="down">
            <DropdownToggle nav>
              <Icon icon={faUser} />
            </DropdownToggle>
            <DropdownMenu right style={{ right: 'auto' }}>
              <DropdownItem>
                <a
                  onClick={() => {}}
                >
                  <Icon icon={faSignOutAlt} className='mr-2' />
                  Logout
                </a>
              </DropdownItem>
            </DropdownMenu>
          </AppHeaderDropdown>
        </Nav>
        <AppAsideToggler className="d-md-down-none" />
      </Fragment>
    );
  }
}

export default Navigation;
